@@ -18,20 +18,25 @@
  *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
-#include "app.h"
-#include "version.h"
+// Qt
+#include <QApplication>
+#include <QCommandLineParser>
 
+// KDE
 #include <KAboutData>
+#include <KCrash>
+#include <KDBusService>
+#include <KLocalizedString>
 #include <Kdelibs4ConfigMigrator>
 
-#include <QCommandLineParser>
-#include <QApplication>
-#include <KLocalizedString>
-#include <KDBusService>
+// KShisen
+#include "app.h"
+#include "debug.h"
 
+Q_LOGGING_CATEGORY(KSHISEN_LOG, "log_kshisen")
 static const char description[] = I18N_NOOP("A KDE game similar to Mahjongg");
 
-int main(int argc, char **argv)
+int main(int argc, char ** argv)
 {
     QApplication a(argc, argv);
 
@@ -42,9 +47,9 @@ int main(int argc, char **argv)
     migrate.migrate();
 
     KLocalizedString::setApplicationDomain("kshisen");
-    KAboutData aboutData(QStringLiteral("kshisen"), i18n("Shisen-Sho"),
-                         QStringLiteral(KSHISEN_VERSION), i18n(description), KAboutLicense::GPL,
-                         i18n("(c) 1997, Mario Weilguni")); 
+
+    KAboutData aboutData(QStringLiteral("kshisen"), i18n("Shisen-Sho"), QStringLiteral("1.9+ #20"),
+                         i18n(description), KAboutLicense::GPL, i18n("(c) 1997, Mario Weilguni"));
     aboutData.setHomepage(QStringLiteral("http://games.kde.org/kshisen"));
     aboutData.addAuthor(i18n("Frederik Schwarzer"), i18n("Current Maintainer"), QStringLiteral("schwarzer@kde.org"));
     aboutData.addAuthor(i18n("Dave Corrie"), i18n("Former Maintainer"), QStringLiteral("kde@davecorrie.com"));
@@ -52,8 +57,10 @@ int main(int argc, char **argv)
     aboutData.addCredit(i18n("Mauricio Piacentini"), i18n("KMahjonggLib integration for KDE4"), QStringLiteral("mauricio@tabuleiro.com"));
     aboutData.addCredit(i18n("Jason Lane"), i18n("Added 'tiles removed' counter<br/>Tile smooth-scaling and window resizing"), QStringLiteral("jglane@btopenworld.com"));
     aboutData.addCredit(i18n("Thanks also to everyone who should be listed here but is not!"));
-    QCommandLineParser parser;
     KAboutData::setApplicationData(aboutData);
+    KCrash::initialize();
+
+    QCommandLineParser parser;
     parser.addVersionOption();
     parser.addHelpOption();
     aboutData.setupCommandLine(&parser);
@@ -64,7 +71,7 @@ int main(int argc, char **argv)
 
     KDBusService service;
 
-    App *app = new App();
+    auto app = new App();
     app->show();
     return a.exec();
 }
